@@ -11,7 +11,7 @@ use lib ();
 $DEBUG              = 0;
 %LIMIT              = ();
 
-=pod 
+=pod
 
 =head1 NAME
 
@@ -21,20 +21,20 @@ CPANPLUS::inc - runtime inclusion of privately bundled modules
 
     ### set up CPANPLUS::inc to do it's thing ###
     BEGIN { use CPANPLUS::inc };
-    
+
     ### enable debugging ###
     use CPANPLUS::inc qw[DEBUG];
 
 =head1 DESCRIPTION
 
-This module enables the use of the bundled modules in the 
+This module enables the use of the bundled modules in the
 C<CPANPLUS/inc> directory of this package. These modules are bundled
 to make sure C<CPANPLUS> is able to bootstrap itself. It will do the
 following things:
 
 =over 4
 
-=item Put a coderef at the beginning of C<@INC> 
+=item Put a coderef at the beginning of C<@INC>
 
 This allows us to decide which module to load, and where to find it.
 For details on what we do, see the C<INTERESTING MODULES> section below.
@@ -42,8 +42,8 @@ Also see the C<CAVEATS> section.
 
 =item Add the full path to the C<CPANPLUS/inc> directory to C<$ENV{PERL5LIB>.
 
-This allows us to find our bundled modules even if we spawn off a new 
-process. Although it's not able to do the selective loading as the 
+This allows us to find our bundled modules even if we spawn off a new
+process. Although it's not able to do the selective loading as the
 coderef in C<@INC> could, it's a good fallback.
 
 =back
@@ -56,32 +56,32 @@ Returns the full path to the C<CPANPLUS/inc> directory.
 
 =head2 CPANPLUS::inc->my_path()
 
-Returns the full path to be added to C<@INC> to load 
+Returns the full path to be added to C<@INC> to load
 C<CPANPLUS::inc> from.
 
 =head2 CPANPLUS::inc->installer_path()
 
-Returns the full path to C<CPANPLUS/inc/installers> directory.
+Returns the full path to the C<CPANPLUS/inc/installers> directory.
 
 =cut
 
 {   my $ext     = '.pm';
     my $file    = (join '/', split '::', __PACKAGE__) . $ext;
-    
-    ### os specific file path, if you're not on unix 
+
+    ### os specific file path, if you're not on unix
     my $osfile  = File::Spec->catfile( split('::', __PACKAGE__) ) . $ext;
-    
+
     ### this returns a unixy path, compensate if you're on non-unix
-    my $path    = File::Spec->rel2abs(  
+    my $path    = File::Spec->rel2abs(
                         File::Spec->catfile( split '/', $INC{$file} )
                     );
-    
+
     ### don't forget to quotemeta; win32 paths are special
     my $qm_osfile = quotemeta $osfile;
     my $path_to_me          = $path; $path_to_me    =~ s/$qm_osfile$//i;
     my $path_to_inc         = $path; $path_to_inc   =~ s/$ext$//i;
     my $path_to_installers  = File::Spec->catdir( $path_to_inc, 'installers' );
-    
+
     sub inc_path        { return $path_to_inc  }
     sub my_path         { return $path_to_me   }
     sub installer_path  { return $path_to_installers }
@@ -99,7 +99,7 @@ got loaded.
 
 =head2 CPANPLUS::inc->original_inc
 
-Returns the value of @INC the way it was when C<CPANPLUS::inc> got 
+Returns the value of @INC the way it was when C<CPANPLUS::inc> got
 loaded.
 
 =head2 CPANPLUS::inc->limited_perl5opt(@modules);
@@ -111,27 +111,27 @@ include facility from C<CPANPLUS::inc>. It will roughly look like:
 
 =cut
 
-{   my $org_opt = $ENV{PERL5OPT}; 
+{   my $org_opt = $ENV{PERL5OPT};
     my $org_lib = $ENV{PERL5LIB};
     my @org_inc = @INC;
 
     sub original_perl5opt   { $org_opt || ''};
     sub original_perl5lib   { $org_lib || ''};
     sub original_inc        { @org_inc };
-    
+
     sub limited_perl5opt    {
         my $pkg = shift;
         my $lim = join ',', @_ or return;
- 
+
         ### -Icp::inc -Mcp::inc=mod1,mod2,mod3
         my $opt =   '-I' . __PACKAGE__->my_path . ' ' .
                     '-M' . __PACKAGE__ . "=$lim";
-    
+
         $opt .=     $Config::Config{'path_sep'} .
                     CPANPLUS::inc->original_perl5opt
-                if  CPANPLUS::inc->original_perl5opt;  
-                
-        return $opt;                
+                if  CPANPLUS::inc->original_perl5opt;
+
+        return $opt;
     }
 }
 
@@ -142,16 +142,16 @@ version we need to find.
 
 It would looks something like this:
 
-    {   File::Fetch             => 0.05,
+    {   File::Fetch             => 0.06,
         IPC::Cmd                => 0.22,
         ....
-    }            
+    }
 
 =cut
 
 {
     my $map = {
-        'File::Fetch'               => '0.05',
+        'File::Fetch'               => '0.06',
         #'File::Spec'                => '0.82', # can't, need it ourselves...
         'IPC::Run'                  => '0.77',
         'IPC::Cmd'                  => '0.24',
@@ -164,20 +164,20 @@ It would looks something like this:
         'Term::UI'                  => '0.04',
         'Archive::Extract'          => '0.07',
         'Archive::Tar'              => '1.23',
-        'IO::Zlib'                  => '1.04',   
+        'IO::Zlib'                  => '1.04',
         'Object::Accessor'          => '0.03',
         'Module::CoreList'          => '1.97',
         #'Config::Auto'             => 0,   # not yet, not using it yet
-    };    
+    };
 
     sub interesting_modules { return $map; }
 }
 
 
-=head1 INTERESTING MODULES    
+=head1 INTERESTING MODULES
 
 C<CPANPLUS::inc> doesn't even bother to try find and find a module
-it's not interested in. A list of I<interesting modules> can be 
+it's not interested in. A list of I<interesting modules> can be
 obtained using the C<interesting_modules> method described above.
 
 Note that all subclassed modules of an C<interesting module> will
@@ -191,18 +191,18 @@ do the following things:
 =item Loop over your @INC
 
 And for every directory it finds there (skipping all non directories
--- see the C<CAVEATS> section), see if the module requested can be 
-found there. 
+-- see the C<CAVEATS> section), see if the module requested can be
+found there.
 
 =item Check the version on every suitable module found in @INC
 
 After a list of modules has been gathered, the version of each of them
 is checked to find the one with the highest version, and return that as
-the module to C<use>. 
+the module to C<use>.
 
-This enables us to use a recent enough version from our own bundled 
-modules, but also to use a I<newer> module found in your path instead, 
-if it is present. Thus having access to bugfixed versions as they are 
+This enables us to use a recent enough version from our own bundled
+modules, but also to use a I<newer> module found in your path instead,
+if it is present. Thus having access to bugfixed versions as they are
 released.
 
 If for some reason no satisfactory version could be found, a warning
@@ -215,8 +215,8 @@ find out exactly what C<CPANPLUS::inc> is doing.
 
 {   my $Loaded;
     my %Cache;
-    
-    
+
+
     ### returns the path to a certain module we found
     sub path_to {
         my $self    = shift;
@@ -224,13 +224,13 @@ find out exactly what C<CPANPLUS::inc> is doing.
 
         ### find the directory
         my $path    = $Cache{$mod}->[0][2] or return;
-        
+
         ### probe them explicitly for a special file, because the
         ### dir we found the file in vs our own paths may point to the
         ### same location, but might not pass an 'eq' test.
 
         ### it's our inc-path
-        return __PACKAGE__->inc_path 
+        return __PACKAGE__->inc_path
                 if -e File::Spec->catfile( $path, '.inc' );
 
         ### it's our installer path
@@ -239,146 +239,148 @@ find out exactly what C<CPANPLUS::inc> is doing.
 
         ### it's just some dir...
         return $path;
-    }        
-    
+    }
+
     ### just a debug method
     sub _show_cache { return \%Cache };
-    
+
     sub import {
         my $pkg = shift;
-    
+
         ### filter DEBUG, and toggle the global
-        map { $LIMIT{$_} = 1 }  grep { /DEBUG/ ? ++$DEBUG && 0 : 1 } @_;     
-    
+        map { $LIMIT{$_} = 1 }  grep { /DEBUG/ ? ++$DEBUG && 0 : 1 } @_;
+
         ### only load once ###
         return 1 if $Loaded++;
-    
+
         ### first, add our own private dir to the end of @INC:
-        {   
-            push @INC,  __PACKAGE__->my_path, __PACKAGE__->inc_path, 
+        {
+            push @INC,  __PACKAGE__->my_path, __PACKAGE__->inc_path,
                         __PACKAGE__->installer_path;
-            
-            ### add the path to this module to PERL5OPT in case 
-            ### we spawn off some programs...
-            ### then add this module to be loaded in PERL5OPT...
-            {   local $^W;
-                $ENV{'PERL5LIB'} .= $Config::Config{'path_sep'} 
-                                 . __PACKAGE__->my_path
-                                 . $Config::Config{'path_sep'} 
-                                 . __PACKAGE__->inc_path;
-                                 
-                $ENV{'PERL5OPT'} = '-M'. __PACKAGE__ . ' ' 
-                                 . ($ENV{'PERL5OPT'} || '');
-            }
-        }      
-    
+
+            ### XXX stop doing this, there's no need for it anymore;
+            ### none of the shell outs need to have this set anymore
+#             ### add the path to this module to PERL5OPT in case
+#             ### we spawn off some programs...
+#             ### then add this module to be loaded in PERL5OPT...
+#             {   local $^W;
+#                 $ENV{'PERL5LIB'} .= $Config::Config{'path_sep'}
+#                                  . __PACKAGE__->my_path
+#                                  . $Config::Config{'path_sep'}
+#                                  . __PACKAGE__->inc_path;
+#
+#                 $ENV{'PERL5OPT'} = '-M'. __PACKAGE__ . ' '
+#                                  . ($ENV{'PERL5OPT'} || '');
+#             }
+        }
+
         ### next, find the highest version of a module that
         ### we care about. very basic check, but will
         ### have to do for now.
-        lib->import( sub { 
+        lib->import( sub {
             my $path    = pop();                # path to the pm
             my $module  = $path or return;      # copy of the path, to munge
             my @parts   = split '/', $path;     # dirs + file name
             my $file    = pop @parts;           # just the file name
             my $map     = __PACKAGE__->interesting_modules;
-            
-            
+
+
             ### translate file name to module name ###
             $module =~ s|/|::|g; $module =~ s/\.pm//i;
-       
+
             my $check_version; my $try;
-            ### does it look like a module we care about?   
-            my ($interesting) = grep { $module =~ /^$_/ } keys %$map;    
-            ++$try if $interesting;  
-              
-            ### do we need to check the version too? 
+            ### does it look like a module we care about?
+            my ($interesting) = grep { $module =~ /^$_/ } keys %$map;
+            ++$try if $interesting;
+
+            ### do we need to check the version too?
             ++$check_version if exists $map->{$module};
-    
+
             ### we don't care ###
             unless( $try ) {
                 warn __PACKAGE__ .": Not interested in '$module'\n" if $DEBUG;
                 return;
-                
-            ### we're not allowed             
+
+            ### we're not allowed
             } elsif ( $try and keys %LIMIT ) {
                 unless( grep { $module =~ /^$_/ } keys %LIMIT  ) {
                     warn __PACKAGE__ .": Limits active, '$module' not allowed ".
                                         "to be loaded" if $DEBUG;
-                    return;    
+                    return;
                 }
             }
-    
+
             ### found filehandles + versions ###
             my @found;
             DIR: for my $dir (@INC) {
                 next DIR unless -d $dir;
-                
+
                 ### get the full path to the module ###
                 my $pm = File::Spec->catfile( $dir, @parts, $file );
-                
+
                 ### open the file if it exists ###
                 if( -e $pm ) {
                     my $fh;
                     unless( open $fh, "$pm" ) {
-                        warn __PACKAGE__ .": Could not open '$pm': $!\n" 
-                            if $DEBUG;    
+                        warn __PACKAGE__ .": Could not open '$pm': $!\n"
+                            if $DEBUG;
                         next DIR;
-                    }      
-    
+                    }
+
                     my $found;
-                    ### XXX stolen from module::load::conditional ###            
+                    ### XXX stolen from module::load::conditional ###
                     while (local $_ = <$fh> ) {
-    
-                        ### the following regexp comes from the 
+
+                        ### the following regexp comes from the
                         ### ExtUtils::MakeMaker documentation.
                         if ( /([\$*])(([\w\:\']*)\bVERSION)\b.*\=/ ) {
-    
+
                             ### this will eval the version in to $VERSION if it
                             ### was declared as $VERSION in the module.
                             ### else the result will be in $res.
                             ### this is a fix on skud's Module::InstalledVersion
-        
+
                             local $VERSION;
                             my $res = eval $_;
-            
+
                             ### default to '0.0' if there REALLY is no version
                             ### all to satisfy warnings
                             $found = $VERSION || $res || '0.0';
-                            
-                            ### found what we came for                    
+
+                            ### found what we came for
                             last if $found;
-                        } 
+                        }
                     }
-    
+
                     ### no version defined at all? ###
                     $found ||= '0.0';
-    
+
                     warn __PACKAGE__ .": Found match for '$module' in '$dir' "
                                      ."with version '$found'\n" if $DEBUG;
-    
+
                     ### reset the position of the filehandle ###
                     seek $fh, 0, 0;
-                
+
                     ### store the found version + filehandle it came from ###
-                    push @found, [ $found, $fh, $dir, $pm ];             
-                }   
-            
+                    push @found, [ $found, $fh, $dir, $pm ];
+                }
+
             } # done looping over all the dirs
-            
+
             ### nothing found? ###
             unless (@found) {
                 warn __PACKAGE__ .": Unable to find any module named "
                                     . "'$module'\n" if $DEBUG;
-                return;         
+                return;
             }
-            
-            ### find highest version 
+
+            ### find highest version
             ### or the one in the same dir as a base module already loaded
             ### or otherwise, the one not bundled
             ### or otherwise the newest
-            my @sorted = sort { 
+            my @sorted = sort {
                             ($b->[0] <=> $a->[0])                   ||
-                            ($Cache{$interesting}  
+                            ($Cache{$interesting}
                                 ?($b->[2] eq $Cache{$interesting}->[0][2]) <=>
                                  ($a->[2] eq $Cache{$interesting}->[0][2])
                                 : 0 )                               ||
@@ -386,20 +388,20 @@ find out exactly what C<CPANPLUS::inc> is doing.
                              ($b->[2] eq __PACKAGE__->inc_path))    ||
                             (-M $a->[3] <=> -M $b->[3])
                           } @found;
-            
+
             warn __PACKAGE__ .": Best match for '$module' is found in "
                              ."'$sorted[0][2]' with version '$sorted[0][0]'\n"
-                    if $DEBUG;                               
-            
+                    if $DEBUG;
+
             if( $check_version and not ($sorted[0][0] >= $map->{$module}) ) {
-                warn __PACKAGE__ .": Cannot find high enough version for " 
+                warn __PACKAGE__ .": Cannot find high enough version for "
                                  ."'$module' -- need '$map->{$module}' but "
                                  ."only found '$sorted[0][0]'. Returning "
                                  ."highest found version but this may cause "
-                                 ."problems\n";                                  
+                                 ."problems\n";
             };
-            
-            ### right, so that damn )#$(*@#)(*@#@ Module::Build makes 
+
+            ### right, so that damn )#$(*@#)(*@#@ Module::Build makes
             ### assumptions about the environment (especially its own tests)
             ### and blows up badly if it's loaded via CP::inc :(
             ### so, if we find a newer version on disk (which would happen when
@@ -414,15 +416,15 @@ find out exactly what C<CPANPLUS::inc> is doing.
                 warn __PACKAGE__ .": Found newer version of 'Module::Build::*' "
                                  ."elsewhere in your path. Pretending to not "
                                  ."have found it\n" if $DEBUG;
-                return;                             
-            }                
-            
+                return;
+            }
+
             ### store what we found for this module
             $Cache{$module} = \@sorted;
-            
+
             ### best matching filehandle ###
             return $sorted[0][1];
-        } );    
+        } );
     }
 }
 
@@ -431,25 +433,25 @@ find out exactly what C<CPANPLUS::inc> is doing.
 =head1 DEBUG
 
 Since this module does C<Clever Things> to your search path, it might
-be nice sometimes to figure out what it's doing, if things don't work 
+be nice sometimes to figure out what it's doing, if things don't work
 as expected. You can enable a debug trace by calling the module like
 this:
 
     use CPANPLUS::inc 'DEBUG';
-    
-This will show you what C<CPANPLUS::inc> is doing, which might look 
+
+This will show you what C<CPANPLUS::inc> is doing, which might look
 something like this:
 
-    CPANPLUS::inc: Found match for 'Params::Check' in     
+    CPANPLUS::inc: Found match for 'Params::Check' in
     '/opt/lib/perl5/site_perl/5.8.3' with version '0.07'
-    CPANPLUS::inc: Found match for 'Params::Check' in 
+    CPANPLUS::inc: Found match for 'Params::Check' in
     '/my/private/lib/CPANPLUS/inc' with version '0.21'
-    CPANPLUS::inc: Best match for 'Params::Check' is found in 
+    CPANPLUS::inc: Best match for 'Params::Check' is found in
     '/my/private/lib/CPANPLUS/inc' with version '0.21'
 
 =head1 CAVEATS
 
-This module has 2 major caveats, that could lead to unexpected 
+This module has 2 major caveats, that could lead to unexpected
 behaviour. But currently I don't know how to fix them, Suggestions
 are much welcomed.
 
@@ -458,21 +460,21 @@ are much welcomed.
 =item On multiple C<use lib> calls, our coderef may not be the first in @INC
 
 If this happens, although unlikely in most situations and not happening
-when calling the shell directly, this could mean that a lower (too low) 
-versioned module is loaded, which might cause failures in the 
+when calling the shell directly, this could mean that a lower (too low)
+versioned module is loaded, which might cause failures in the
 application.
 
 =item Non-directories in @INC
 
-Non-directories are right now skipped by CPANPLUS::inc. They could of 
-course lead us to newer versions of a module, but it's too tricky to 
-verify if they would. Therefor they are skipped. In the worst case 
+Non-directories are right now skipped by CPANPLUS::inc. They could of
+course lead us to newer versions of a module, but it's too tricky to
+verify if they would. Therefor they are skipped. In the worst case
 scenario we'll find the sufficing version bundled with CPANPLUS.
 
 
 =cut
 
-1;    
+1;
 
 # Local variables:
 # c-indentation-style: bsd
@@ -480,4 +482,4 @@ scenario we'll find the sufficing version bundled with CPANPLUS.
 # indent-tabs-mode: nil
 # End:
 # vim: expandtab shiftwidth=4:
-    
+
